DataTesterConfig

Struct DataTesterConfig 

pub struct DataTesterConfig {
Show 34 fields pub base: DataActorConfig, pub instrument_ids: Vec<InstrumentId>, pub client_id: Option<ClientId>, pub bar_types: Option<Vec<BarType>>, pub subscribe_book_deltas: bool, pub subscribe_book_depth: bool, pub subscribe_book_at_interval: bool, pub subscribe_quotes: bool, pub subscribe_trades: bool, pub subscribe_mark_prices: bool, pub subscribe_index_prices: bool, pub subscribe_funding_rates: bool, pub subscribe_bars: bool, pub subscribe_instrument: bool, pub subscribe_instrument_status: bool, pub subscribe_instrument_close: bool, pub subscribe_option_greeks: bool, pub subscribe_params: Option<Params>, pub request_params: Option<Params>, pub can_unsubscribe: bool, pub request_instruments: bool, pub request_quotes: bool, pub request_trades: bool, pub request_bars: bool, pub request_book_snapshot: bool, pub request_book_deltas: bool, pub request_funding_rates: bool, pub book_type: BookType, pub book_depth: Option<usize>, pub book_interval_ms: usize, pub book_levels_to_print: usize, pub manage_book: bool, pub log_data: bool, pub stats_interval_secs: u64,
}
Configuration for the data tester actor.

Fields

base: DataActorConfig

Base data actor configuration.

instrument_ids: Vec<InstrumentId>

Instrument IDs to subscribe to.

client_id: Option<ClientId>

Client ID to use for subscriptions.

bar_types: Option<Vec<BarType>>

Bar types to subscribe to.

subscribe_book_deltas: bool

Whether to subscribe to order book deltas.

subscribe_book_depth: bool

Whether to subscribe to order book depth snapshots.

subscribe_book_at_interval: bool

Whether to subscribe to order book at interval.

subscribe_quotes: bool

Whether to subscribe to quotes.

subscribe_trades: bool

Whether to subscribe to trades.

subscribe_mark_prices: bool

Whether to subscribe to mark prices.

subscribe_index_prices: bool

Whether to subscribe to index prices.

subscribe_funding_rates: bool

Whether to subscribe to funding rates.

subscribe_bars: bool

Whether to subscribe to bars.

subscribe_instrument: bool

Whether to subscribe to instrument updates.

subscribe_instrument_status: bool

Whether to subscribe to instrument status.

subscribe_instrument_close: bool

Whether to subscribe to instrument close.

subscribe_option_greeks: bool

Whether to subscribe to option greeks.

subscribe_params: Option<Params>

Optional parameters passed to all subscribe calls.

request_params: Option<Params>

Optional parameters passed to all request calls.

can_unsubscribe: bool

Whether unsubscribe is supported on stop.

request_instruments: bool

Whether to request instruments on start.

request_quotes: bool

Whether to request historical quotes.

request_trades: bool

Whether to request historical trades (not yet implemented).

request_bars: bool

Whether to request historical bars.

request_book_snapshot: bool

Whether to request order book snapshots.

request_book_deltas: bool

Whether to request historical order book deltas (not yet implemented).

request_funding_rates: bool

Whether to request historical funding rates.

book_type: BookType

Book type for order book subscriptions.

book_depth: Option<usize>

Order book depth for subscriptions.

book_interval_ms: usize

Order book interval in milliseconds for at_interval subscriptions.

book_levels_to_print: usize

Number of order book levels to print when logging.

manage_book: bool

Whether to manage local order book from deltas.

log_data: bool

Whether to log received data.

stats_interval_secs: u64

Stats logging interval in seconds (0 to disable).

Implementations

Source

impl DataTesterConfig

pub fn builder() -> DataTesterConfigBuilder

Create an instance of DataTesterConfig using the builder syntax

Source

impl DataTesterConfig

pub fn validate(&self) -> ConfigResult<()>

Validates the data tester configuration, collecting every field violation.

Errors

Returns a [ConfigError] (a [ConfigError::Multiple] when more than one field is invalid) if any field fails validation.

pub fn new(client_id: ClientId, instrument_ids: Vec<InstrumentId>) -> Self

Creates a new DataTesterConfig instance with minimal settings.